@@ -27,6 +27,7 @@
 #include  <QFontDialog>
 #include  <QColorDialog>
 #include  <QPainter>
+#include  <QStackedLayout>
 
 #include  "ConfigDlgImpl.h"
 
@@ -45,7 +46,7 @@
 using namespace std;
 using namespace pearl;
 
-//ttt1 simple / detailed files tab, with "simple" only allowing to "create backups in ..."
+//ttt2 simple / detailed files tab, with "simple" only allowing to "create backups in ..."
 //=====================================================================================================================
 //=====================================================================================================================
 //=====================================================================================================================
@@ -241,7 +242,7 @@ class EventFilter : public QObject
     {
         if (QEvent::Paint != pEvent->type())
         {
-            qDebug("%s %d", pObj->objectName().toUtf8().data(), (int)pEvent->type());
+            qDebug("%s %d", pObj->objectName().toUtf8().constData(), (int)pEvent->type());
         }
 
         static bool b (true);
@@ -280,6 +281,10 @@ ConfigDlgImpl::ConfigDlgImpl(TransfConfig& transfCfg, CommonData* pCommonData, Q
 {
     setupUi(this);
 
+#ifdef DISABLE_CHECK_FOR_UPDATES
+    m_pCheckForUpdatesCkB->hide();
+#endif
+
     if (!bFull)
     {
         m_pMainTabWidget->removeTab(6);
@@ -297,6 +302,7 @@ ConfigDlgImpl::ConfigDlgImpl(TransfConfig& transfCfg, CommonData* pCommonData, Q
         //m_pIconConfW->hide();
         //m_pFontsW->hide();
         m_pNormalizeGrp->hide();
+        m_pRenamerGrp->hide();
     }
 
     m_pSourceDirF->hide();
@@ -332,15 +338,11 @@ ConfigDlgImpl::ConfigDlgImpl(TransfConfig& transfCfg, CommonData* pCommonData, Q
                         const Id3V2Frame* pFrm (vpFrames[i]);
                         if ('T' == pFrm->m_szName[0] && pFrm->m_bHasLatin1NonAscii)
                         {
-                            Id3V2FrameDataLoader wrp (*pFrm);
-                            const char* pData (wrp.getData());
-                            CB_ASSERT (0 == pData[0]); // "Latin1" encoding
-                            QByteArray arr (pData + 1, pFrm->m_nMemDataSize - 1);
                             if (!qstr.isEmpty())
                             {
                                 qstr += '\n';
                             }
-                            qstr += QString::fromLatin1(arr);
+                            qstr += convStr(pFrm->getUtf8String());
                         }
                     }
                 }
@@ -362,75 +364,51 @@ ConfigDlgImpl::ConfigDlgImpl(TransfConfig& transfCfg, CommonData* pCommonData, Q
     //tab_3->installEventFilter(pEventFilter);
     */
 
-    m_pSrcDirE->setText(toNativeSeparators(convStr(getSepTerminatedDir(transfCfg.getSrcDir()))));
+    {
 
-    { // ProcOrig
-        switch (transfCfg.m_optionsWrp.m_opt.m_nProcOrigChange)
         {
-        case 0: m_pPODontChangeRB->setChecked(true); break;
-        case 1: m_pPOEraseRB->setChecked(true); break;
-        case 2: m_pPOMoveAlwaysChangeRB->setChecked(true); break;
-        case 3: m_pPOMoveChangeIfNeededRB->setChecked(true); break;
-        case 4: m_pPOChangeNameRB->setChecked(true); break;
-        case 5: m_pPOMoveOrEraseRB->setChecked(true); break;
-        default:
-            CB_ASSERT(false); // the constructor of TransfConfig should have detected it
-        }
+            delete m_pRemovableL;
 
-        if (transfCfg.m_optionsWrp.m_opt.m_bProcOrigUseLabel) { m_pPOUseLabelRB->setChecked(true); } else { m_pPODontUseLabelRB->setChecked(true); }
-        if (transfCfg.m_optionsWrp.m_opt.m_bProcOrigAlwayUseCounter) { m_pPOAlwaysUseCounterRB->setChecked(true); } else { m_pPOUseCounterIfNeededRB->setChecked(true); }
+            delete m_pFileSettingsW->layout();
+            m_pFileSettingsLayout = new QStackedLayout(m_pFileSettingsW);
+            //m_pFileSettingsLayout->setContentsMargins(0, 50, 50, 0);
+            //m_pFileSettingsW->setLayout(m_pFileSettingsLayout);
+            m_pFileSettingsLayout->addWidget(m_pSimpleViewTab);
+            m_pFileSettingsLayout->addWidget(m_pFullViewTab);
+
+            delete m_pDetailsTabWidget;
+        }
 
         m_pPODestE->setText(toNativeSeparators(convStr(getSepTerminatedDir(transfCfg.getProcOrigDir()))));
-    }
-
-    { // UnprocOrig
-        switch (transfCfg.m_optionsWrp.m_opt.m_nUnprocOrigChange)
-        {
-        case 0: m_pUODontChangeRB->setChecked(true); break;
-        case 1: m_pUOEraseRB->setChecked(true); break;
-        case 2: m_pUOMoveAlwaysChangeRB->setChecked(true); break;
-        case 3: m_pUOMoveChangeIfNeededRB->setChecked(true); break;
-        case 4: m_pUOChangeNameRB->setChecked(true); break;
-        default:
-            CB_ASSERT(false); // the constructor of TransfConfig should have detected it
-        }
-
-        if (transfCfg.m_optionsWrp.m_opt.m_bUnprocOrigUseLabel) { m_pUOUseLabelRB->setChecked(true); } else { m_pUODontUseLabelRB->setChecked(true); }
-        if (transfCfg.m_optionsWrp.m_opt.m_bUnprocOrigAlwayUseCounter) { m_pUOAlwaysUseCounterRB->setChecked(true); } else { m_pUOUseCounterIfNeededRB->setChecked(true); }
-
+        m_pPODest2E->setText(m_pPODestE->text());
         m_pUODestE->setText(toNativeSeparators(convStr(getSepTerminatedDir(transfCfg.getUnprocOrigDir()))));
-    }
+        m_pProcDestE->setText(toNativeSeparators(convStr(getSepTerminatedDir(transfCfg.getProcessedDir()))));
+        m_pTempDestE->setText(toNativeSeparators(convStr(getSepTerminatedDir(transfCfg.getTempDir()))));
+        m_pCompDestE->setText(toNativeSeparators(convStr(getSepTerminatedDir(transfCfg.getCompDir()))));
 
-    { // Processed
-        switch (transfCfg.m_optionsWrp.m_opt.m_nProcessedCreate)
+        m_pSrcDirE->setText(toNativeSeparators(convStr(getSepTerminatedDir(transfCfg.getSrcDir()))));
+
+        //setSimpleViewOpt(transfCfg.m_options); //!!! pointless; doesn't work if keepTime is true; anyway, the on_m_pSimpleViewB_clicked() call below will select the right radiobutton
+        setFullViewOpt(transfCfg.m_options); // !!! the buttons should be set for both views
+        setSimpleViewOpt(transfCfg.m_options);
+
+        TransfConfig::Options opt (transfCfg.m_options);
+
+        if (opt.asBackup() == opt || opt.asNonBackup() == opt)
         {
-        case 0: m_pProcDontCreateRB->setChecked(true); break;
-        case 1: m_pProcCreateAlwaysChangeRB->setChecked(true); break;
-        case 2: m_pProcCreateChangeIfNeededRB->setChecked(true); break;
-        default:
-            CB_ASSERT(false); // the constructor of TransfConfig should have detected it
+            m_pSimpleViewB->setChecked(true);
+            on_m_pSimpleViewB_clicked();
+        }
+        else
+        {
+            m_pFullViewB->setChecked(true);
+            on_m_pFullViewB_clicked();
         }
 
-        if (transfCfg.m_optionsWrp.m_opt.m_bProcessedUseLabel) { m_pProcUseLabelRB->setChecked(true); } else { m_pProcDontUseLabelRB->setChecked(true); }
-        if (transfCfg.m_optionsWrp.m_opt.m_bProcessedAlwayUseCounter) { m_pProcAlwaysUseCounterRB->setChecked(true); } else { m_pProcUseCounterIfNeededRB->setChecked(true); }
-        if (transfCfg.m_optionsWrp.m_opt.m_bProcessedUseSeparateDir) { m_pProcUseSeparateDirRB->setChecked(true); } else { m_pProcUseSrcRB->setChecked(true); }
 
-        m_pProcDestE->setText(toNativeSeparators(convStr(getSepTerminatedDir(transfCfg.getProcessedDir()))));
+        m_pKeepOrigTimeCkB->setChecked(transfCfg.m_options.m_bKeepOrigTime);
     }
 
-    {
-        m_pKeepOrigTimeCkB->setChecked(transfCfg.m_optionsWrp.m_opt.m_bKeepOrigTime);
-    }
-
-    { // Temp
-        if (transfCfg.m_optionsWrp.m_opt.m_bTempCreate) { m_pTempCreateRB->setChecked(true); } else { m_pTempDontCreateRB->setChecked(true); }
-        m_pTempDestE->setText(toNativeSeparators(convStr(getSepTerminatedDir(transfCfg.getTempDir()))));
-    }
-
-    { // Comp
-        if (transfCfg.m_optionsWrp.m_opt.m_bCompCreate) { m_pCompCreateRB->setChecked(true); } else { m_pCompDontCreateRB->setChecked(true); }
-        m_pCompDestE->setText(toNativeSeparators(convStr(getSepTerminatedDir(transfCfg.getCompDir()))));
-    }
 
 
     // -------------------------------------------- ignored ------------------------------------------------------
@@ -502,12 +480,27 @@ ConfigDlgImpl::ConfigDlgImpl(TransfConfig& transfCfg, CommonData* pCommonData, Q
 
     { // locale
         QStringList lNames;
+        set<QString> s;
+//set<QString> s1;
         QList<QByteArray> l (QTextCodec::availableCodecs());
         for (int i = 0, n = l.size(); i < n; ++i)
         {
-            lNames << QString::fromLatin1(l[i]);
+            //lNames << QString::fromLatin1(l[i]);
+            //lNames << QTextCodec::codecForName(l[i])->name();
+            s.insert(QTextCodec::codecForName(l[i])->name()); // a codec is known by several names; by doing this we eliminate redundant names and make the list a lot smaller
+            //s.insert(QTextCodec::codecForName(l[i])->name() + QString::fromLatin1(l[i]));
+//qDebug("%s", (QString::fromLatin1(l[i]) + "  /  " + QTextCodec::codecForName(l[i])->name()).toUtf8().data());
+//s1.insert(QTextCodec::codecForName(l[i])->name() + "  /  " + QString::fromLatin1(l[i]));
         }
 
+        for (set<QString>::const_iterator it = s.begin(); it != s.end(); ++it)
+        {
+            lNames << *it;
+        }
+//for (set<QString>::const_iterator it = s1.begin(); it != s1.end(); ++it) { qDebug("%s", it->toUtf8().data()); }
+
+//lNames.sort();
+
         m_pLocaleCbB->addItems(lNames);
         int n (m_pLocaleCbB->findText(m_pCommonData->m_locale));
         if (-1 == n) { n = 0; }
@@ -516,10 +509,14 @@ ConfigDlgImpl::ConfigDlgImpl(TransfConfig& transfCfg, CommonData* pCommonData, Q
 
     { // case
         QStringList lNames;
-        lNames << "Lower case: first part. second part.";
+        /*lNames << "Lower case: first part. second part.";
         lNames << "Upper case: FIRST PART. SECOND PART.";
         lNames << "Title case: First Part. Second Part.";
-        lNames << "Phrase case: First part. Second part.";
+        lNames << "Sentence case: First part. Second part.";*/ // ttt2 perhaps put this back; as of 2009.10.15, "." is no longer supported as a sentence ending
+        lNames << "lower case";
+        lNames << "UPPER CASE";
+        lNames << "Title Case";
+        lNames << "Sentence case";
 
         m_pArtistsCaseCbB->addItems(lNames);
         m_pOthersCaseCbB->addItems(lNames);
@@ -559,6 +556,7 @@ ConfigDlgImpl::ConfigDlgImpl(TransfConfig& transfCfg, CommonData* pCommonData, Q
     {  //misc
         m_pScanAtStartupCkB->setChecked(m_pCommonData->m_bScanAtStartup);
         m_pFastSaveCkB->setChecked(m_pCommonData->useFastSave());
+        m_pShowExportCkB->setChecked(m_pCommonData->m_bShowExport);
         m_pShowDebugCkB->setChecked(m_pCommonData->m_bShowDebug);
         m_pShowSessCkB->setChecked(m_pCommonData->m_bShowSessions);
         m_pNormalizerE->setText(convStr(m_pCommonData->m_strNormalizeCmd));
@@ -583,9 +581,16 @@ ConfigDlgImpl::ConfigDlgImpl(TransfConfig& transfCfg, CommonData* pCommonData, Q
         m_pIconSizeSB->setValue(m_pCommonData->m_nMainWndIconSize);
         m_pAutoSizeIconsCkB->setChecked(m_pCommonData->m_bAutoSizeIcons);
         m_pKeepOneValidImgCkB->setChecked(m_pCommonData->m_bKeepOneValidImg);
+        m_pWmpCkB->setChecked(m_pCommonData->m_bWmpVarArtists);
+        m_pItunesCkB->setChecked(m_pCommonData->m_bItunesVarArtists);
         m_pMaxImgSizeSB->setValue(ImageInfo::MAX_IMAGE_SIZE/1024);
         m_pTraceToFileCkB->setChecked(m_pCommonData->isTraceToFileEnabled());
 
+        m_pInvalidCharsE->setText(convStr(m_pCommonData->m_strRenamerInvalidChars));
+        m_pInvalidReplacementE->setText(convStr(m_pCommonData->m_strRenamerReplacementString));
+
+        m_pCheckForUpdatesCkB->setChecked("yes" == m_pCommonData->m_strCheckForNewVersions);
+
         m_generalFont = m_pCommonData->getNewGeneralFont();
         m_pDecrLabelFontSB->setValue(m_pCommonData->getLabelFontSizeDecr());
         m_fixedFont = m_pCommonData->getNewFixedFont();
@@ -613,6 +618,11 @@ ConfigDlgImpl::ConfigDlgImpl(TransfConfig& transfCfg, CommonData* pCommonData, Q
     m_pSrcDirE->setFocus();
 
     { QAction* p (new QAction(this)); p->setShortcut(QKeySequence("F1")); connect(p, SIGNAL(triggered()), this, SLOT(onHelp())); addAction(p); }
+
+    m_pInvalidCharsE->setToolTip("Characters in this list get replaced with the string below, in \"Replace with\"\n\n"
+        "An underlined font is used to allow spaces to be seen");
+    m_pInvalidReplacementE->setToolTip("This string replaces invalid characters in the file renamer\"\n\n"
+        "An underlined font is used to allow spaces to be seen");
 }
 
 
@@ -675,7 +685,8 @@ void SessionSettings::saveTransfConfig(const TransfConfig& transfConfig)
     }*/
 }
 
-void SessionSettings::loadTransfConfig(TransfConfig& transfConfig) const
+// returns false if there was some error while loading (so the user can be told about defaults being used and those defaults could get saved)
+bool SessionSettings::loadTransfConfig(TransfConfig& transfConfig) const
 {
     try
     {
@@ -690,11 +701,13 @@ void SessionSettings::loadTransfConfig(TransfConfig& transfConfig) const
                 m_pSettings->value("transformation/options", -1).toInt()
             );
         transfConfig = tc;
+        return !tc.hadInitError();
     }
     catch (const IncorrectDirName&)
     {
         TransfConfig tc ("*", "*", "*", "*", "*", "*", -1);
         transfConfig = tc;
+        return false;
     }
 }
 
@@ -731,6 +744,7 @@ void initDefaultCustomTransf(int k, vector<vector<int> >& vv, CommonData* pCommo
         v.push_back(pCommonData->getTransfPos(InnerNonAudioRemover::getClassName()));
         v.push_back(pCommonData->getTransfPos(TruncatedMpegDataStreamRemover::getClassName()));
         v.push_back(pCommonData->getTransfPos(VbrRepairer::getClassName()));
+        v.push_back(pCommonData->getTransfPos(MismatchedXingRemover::getClassName())); // !!! takes care of broken Xing headers for CBR files (VbrRepairer only deals with VBR files)
         break;
 
     case 1:
@@ -752,7 +766,25 @@ void initDefaultCustomTransf(int k, vector<vector<int> >& vv, CommonData* pCommo
         break;
 
     case 3: // CUSTOM_TRANSF_CNT
-        //v.push_back(pCommonData->getTransfPos(InnerNonAudioRemover::getClassName())); //ttt1 see if there is a better way to set this up
+        v.push_back(pCommonData->getTransfPos(SingleBitRepairer::getClassName()));
+        v.push_back(pCommonData->getTransfPos(InnerNonAudioRemover::getClassName()));
+        v.push_back(pCommonData->getTransfPos(TruncatedMpegDataStreamRemover::getClassName()));
+        v.push_back(pCommonData->getTransfPos(VbrRepairer::getClassName()));
+        v.push_back(pCommonData->getTransfPos(MismatchedXingRemover::getClassName())); // !!! takes care of broken Xing headers for CBR files (VbrRepairer only deals with VBR files)
+
+        v.push_back(pCommonData->getTransfPos(Id3V2Rescuer::getClassName()));
+        v.push_back(pCommonData->getTransfPos(UnsupportedId3V2Remover::getClassName()));
+        v.push_back(pCommonData->getTransfPos(MultipleId3StreamRemover::getClassName()));
+        //v.push_back(pCommonData->getTransfPos(Id3V1ToId3V2Copier::getClassName()));
+
+        //v.push_back(pCommonData->getTransfPos(InnerNonAudioRemover::getClassName()));
+        v.push_back(pCommonData->getTransfPos(UnknownDataStreamRemover::getClassName()));
+        v.push_back(pCommonData->getTransfPos(BrokenDataStreamRemover::getClassName()));
+        v.push_back(pCommonData->getTransfPos(UnsupportedDataStreamRemover::getClassName()));
+        v.push_back(pCommonData->getTransfPos(TruncatedMpegDataStreamRemover::getClassName()));
+        v.push_back(pCommonData->getTransfPos(NullStreamRemover::getClassName()));
+        //v.push_back(pCommonData->getTransfPos(MultipleId3StreamRemover::getClassName()));
+        //v.push_back(pCommonData->getTransfPos(MismatchedXingRemover::getClassName()));
         break;
 
     default:
@@ -877,42 +909,35 @@ void ConfigDlgImpl::getTransfData()
 }
 
 
-
 void ConfigDlgImpl::on_m_pOkB_clicked()
 {
+    {
+        string strInv (convStr(m_pInvalidCharsE->text()));
+        string strRepl (convStr(m_pInvalidReplacementE->text()));
+        if (!strInv.empty())
+        {
+            string::size_type n (strRepl.find_first_of(strInv));
+            if (string::npos != n)
+            {
+                QMessageBox::critical(this, "Error", QString("You can't have '") + strRepl[n] + "' in both the list of invalid characters and the string that invalid characters are replaced with.");
+                return;
+            }
+        }
+    }
+
     //logState("on_m_pOkB_clicked 1");
     try
     {
-        TransfConfig::OptionsWrp wrp;
-        wrp.m_nVal = 0;
-
-        wrp.m_opt.m_nProcOrigChange = m_pPODontChangeRB->isChecked() ? 0 : m_pPOEraseRB->isChecked() ? 1 : m_pPOMoveAlwaysChangeRB->isChecked() ? 2 : m_pPOMoveChangeIfNeededRB->isChecked() ? 3 : m_pPOChangeNameRB->isChecked() ? 4 : m_pPOMoveOrEraseRB->isChecked() ? 5 : 7;
-        wrp.m_opt.m_bProcOrigUseLabel = m_pPOUseLabelRB->isChecked();
-        wrp.m_opt.m_bProcOrigAlwayUseCounter = m_pPOAlwaysUseCounterRB->isChecked();
-
-        wrp.m_opt.m_nUnprocOrigChange = m_pUODontChangeRB->isChecked() ? 0 : m_pUOEraseRB->isChecked() ? 1 : m_pUOMoveAlwaysChangeRB->isChecked() ? 2 : m_pUOMoveChangeIfNeededRB->isChecked() ? 3 : m_pUOChangeNameRB->isChecked() ? 4 : 7;
-        wrp.m_opt.m_bUnprocOrigUseLabel = m_pUOUseLabelRB->isChecked();
-        wrp.m_opt.m_bUnprocOrigAlwayUseCounter = m_pUOAlwaysUseCounterRB->isChecked();
-
-        wrp.m_opt.m_nProcessedCreate = m_pProcDontCreateRB->isChecked() ? 0 : m_pProcCreateAlwaysChangeRB->isChecked() ? 1 : m_pProcCreateChangeIfNeededRB->isChecked() ? 2 : 3;
-        wrp.m_opt.m_bProcessedUseLabel = m_pProcUseLabelRB->isChecked();
-        wrp.m_opt.m_bProcessedAlwayUseCounter = m_pProcAlwaysUseCounterRB->isChecked();
-        wrp.m_opt.m_bProcessedUseSeparateDir = m_pProcUseSeparateDirRB->isChecked();
-
-        wrp.m_opt.m_bTempCreate = m_pTempCreateRB->isChecked();
-
-        wrp.m_opt.m_bCompCreate = m_pCompCreateRB->isChecked();
-
-        wrp.m_opt.m_bKeepOrigTime = m_pKeepOrigTimeCkB->isChecked();
+        TransfConfig::Options opt (getOpt());
 
         TransfConfig cfg (
                 getNonSepTerminatedDir(convStr(fromNativeSeparators(m_pSrcDirE->text()))),
-                getNonSepTerminatedDir(convStr(fromNativeSeparators(m_pPODestE->text()))),
+                getNonSepTerminatedDir(convStr(fromNativeSeparators((m_pSimpleViewB->isChecked() ? m_pPODest2E : m_pPODestE)->text()))),
                 getNonSepTerminatedDir(convStr(fromNativeSeparators(m_pUODestE->text()))),
                 getNonSepTerminatedDir(convStr(fromNativeSeparators(m_pProcDestE->text()))),
                 getNonSepTerminatedDir(convStr(fromNativeSeparators(m_pTempDestE->text()))),
                 getNonSepTerminatedDir(convStr(fromNativeSeparators(m_pCompDestE->text()))),
-                wrp.m_nVal
+                opt.getVal()
             );
         m_transfCfg = cfg;
 
@@ -947,13 +972,13 @@ void ConfigDlgImpl::on_m_pOkB_clicked()
 
         {
             m_pCommonData->m_locale = m_pLocaleCbB->currentText().toLatin1();
-            m_pCommonData->m_pCodec = (QTextCodec::codecForName(m_pCommonData->m_locale));
+            m_pCommonData->m_pCodec = QTextCodec::codecForName(m_pCommonData->m_locale);
             CB_ASSERT (0 != m_pCommonData->m_pCodec);
         }
 
         { // case
-            m_pCommonData->m_eCaseForArtists = (CommonData::Case)m_pArtistsCaseCbB->currentIndex();
-            m_pCommonData->m_eCaseForOthers = (CommonData::Case)m_pOthersCaseCbB->currentIndex();
+            m_pCommonData->m_eCaseForArtists = (TextCaseOptions)m_pArtistsCaseCbB->currentIndex(); //ttt2 perhaps allow NONE
+            m_pCommonData->m_eCaseForOthers = (TextCaseOptions)m_pOthersCaseCbB->currentIndex();
         }
 
         { // colors
@@ -968,6 +993,7 @@ void ConfigDlgImpl::on_m_pOkB_clicked()
         { // misc
             m_pCommonData->m_bScanAtStartup = m_pScanAtStartupCkB->isChecked();
             m_pCommonData->setFastSave(m_pFastSaveCkB->isChecked(), CommonData::UPDATE_TRANSFORMS);
+            m_pCommonData->m_bShowExport = m_pShowExportCkB->isChecked();
             m_pCommonData->m_bShowDebug = m_pShowDebugCkB->isChecked();
             m_pCommonData->m_bShowSessions = m_pShowSessCkB->isChecked();
             m_pCommonData->m_strNormalizeCmd = convStr(m_pNormalizerE->text());
@@ -979,17 +1005,24 @@ void ConfigDlgImpl::on_m_pOkB_clicked()
             m_pCommonData->m_nMainWndIconSize = m_pIconSizeSB->value();
             m_pCommonData->m_bAutoSizeIcons = m_pAutoSizeIconsCkB->isChecked();
             m_pCommonData->m_bKeepOneValidImg = m_pKeepOneValidImgCkB->isChecked();
-            ImageInfo::MAX_IMAGE_SIZE = m_pMaxImgSizeSB->value()*1024; //ttt1 inconsistent to keep this in static var and the others in CommonData; perhaps switch to a global CommonData that anybody can access, without passing it in params
+            m_pCommonData->m_bWmpVarArtists = m_pWmpCkB->isChecked();
+            m_pCommonData->m_bItunesVarArtists = m_pItunesCkB->isChecked();
+            ImageInfo::MAX_IMAGE_SIZE = m_pMaxImgSizeSB->value()*1024; //ttt2 inconsistent to keep this in static var and the others in CommonData; perhaps switch to a global CommonData that anybody can access, without passing it in params
             m_pCommonData->setTraceToFile(m_pTraceToFileCkB->isChecked());
 
             m_pCommonData->setFontInfo(convStr(m_generalFont.family()), m_generalFont.pointSize(), m_pDecrLabelFontSB->value(), convStr(m_fixedFont.family()), m_fixedFont.pointSize());
+
+            m_pCommonData->m_strRenamerInvalidChars = convStr(m_pInvalidCharsE->text());
+            m_pCommonData->m_strRenamerReplacementString = convStr(m_pInvalidReplacementE->text());
+
+            m_pCommonData->m_strCheckForNewVersions = m_pCheckForUpdatesCkB->isChecked() ? "yes" : "no";
         }
 
         accept();
     }
     catch (const IncorrectDirName&)
     {
-        QMessageBox::critical(this, "Invalid folder name", "A folder name is incorrect."); //ttt1 say which name
+        QMessageBox::critical(this, "Invalid folder name", "A folder name is incorrect."); //ttt2 say which name
     }
 }
 
@@ -1003,7 +1036,7 @@ void ConfigDlgImpl::on_m_pCancelB_clicked()
 void ConfigDlgImpl::on_m_pChangeGenFontB_clicked()
 {
     bool bOk;
-    QFont font = QFontDialog::getFont(&bOk, m_generalFont, this); //ttt1 see if possible to remove "What's this" button
+    QFont font = QFontDialog::getFont(&bOk, m_generalFont, this); //ttt2 see if possible to remove "What's this" button
     if (!bOk) { return; }
 
     m_generalFont = font;
@@ -1028,6 +1061,11 @@ void ConfigDlgImpl::setFontLabels()
     m_pGeneralFontL->setFont(m_generalFont);
     m_pFixedFontL->setText(QString("%1, %2pt").arg(m_fixedFont.family()).arg(m_fixedFont.pointSize()));
     m_pFixedFontL->setFont(m_fixedFont);
+
+    QFont f (m_fixedFont);
+    f.setUnderline(true);
+    m_pInvalidReplacementE->setFont(f);
+    m_pInvalidCharsE->setFont(f);
 }
 
 
@@ -1035,7 +1073,7 @@ void ConfigDlgImpl::setFontLabels()
 
 void ConfigDlgImpl::logState(const char* /*szPlace*/) const
 {
-    /*cout << szPlace << ": m_filter.m_vSelDirs=" << m_pCommonData->m_filter.m_vSelDirs.size() << " m_availableDirs.m_vDirs=" << m_availableDirs.m_vDirs.size() << " m_selectedDirs.m_vSelDirs=" << m_selectedDirs.m_vDirs.size() << endl;*/
+    /*cout << szPlace << ": m_filter.m_vSelDirs=" << m_pCommonData->m_filter.m_vSelDirs.size() << " m_availableDirs.m_vstrDirs=" << m_availableDirs.m_vstrDirs.size() << " m_selectedDirs.m_vSelDirs=" << m_selectedDirs.m_vstrDirs.size() << endl;*/
 }
 
 
@@ -1115,11 +1153,11 @@ void ConfigDlgImpl::onHelp()
     case 1: openHelp("260_config_ignored_notes.html"); break;
     case 2: openHelp("270_config_custom_transf.html"); break;
     case 3: openHelp("290_config_transf_params.html"); break;
-
-    case 5: openHelp("280_config_quality.html"); break;
-
+    case 4: openHelp("292_config_visible_transf.html"); break;
+    case 5: openHelp("295_config_quality.html"); break;
+    case 6: openHelp("297_config_colors.html"); break;
     case 7: openHelp("300_config_others.html"); break;
-    //ttt0 revise as needed
+    //tttr revise as needed
 
     default: /*openHelp("index.html");*/ break;
     }
@@ -1167,10 +1205,157 @@ void ConfigDlgImpl::on_m_pFastSaveCkB_stateChanged()
 }
 
 
+
+TransfConfig::Options ConfigDlgImpl::getSimpleViewOpt() // doesn't set m_bKeepOrigTime
+{
+    TransfConfig::Options opt (getFullViewOpt());
+    if (m_pBackupCustomRB->isChecked()) { return opt; }
+
+    if (m_pDontCreateBackupRB->isChecked()) { return opt.asNonBackup(); }
+
+    return opt.asBackup();
+}
+
+
+TransfConfig::Options ConfigDlgImpl::getFullViewOpt() // doesn't set m_bKeepOrigTime
+{
+    TransfConfig::Options opt;
+
+    opt.m_eProcOrigChange = m_pPODontChangeRB->isChecked() ? TransfConfig::Options::PO_DONT_CHG : m_pPOEraseRB->isChecked() ? TransfConfig::Options::PO_ERASE : m_pPOMoveAlwaysChangeRB->isChecked() ? TransfConfig::Options::PO_MOVE_ALWAYS_RENAME : m_pPOMoveChangeIfNeededRB->isChecked() ? TransfConfig::Options::PO_MOVE_RENAME_IF_USED : m_pPOChangeNameRB->isChecked() ? TransfConfig::Options::PO_RENAME_SAME_DIR : m_pPOMoveOrEraseRB->isChecked() ? TransfConfig::Options::PO_MOVE_OR_ERASE : TransfConfig::Options::ProcOrig(7);
+    CB_ASSERT (7 != opt.m_eProcOrigChange);
+    opt.m_bProcOrigUseLabel = m_pPOUseLabelRB->isChecked();
+    opt.m_bProcOrigAlwayUseCounter = m_pPOAlwaysUseCounterRB->isChecked();
+
+    opt.m_eUnprocOrigChange = m_pUODontChangeRB->isChecked() ? TransfConfig::Options::UPO_DONT_CHG : m_pUOEraseRB->isChecked() ? TransfConfig::Options::UPO_ERASE : m_pUOMoveAlwaysChangeRB->isChecked() ? TransfConfig::Options::UPO_MOVE_ALWAYS_RENAME : m_pUOMoveChangeIfNeededRB->isChecked() ? TransfConfig::Options::UPO_MOVE_RENAME_IF_USED : m_pUOChangeNameRB->isChecked() ? TransfConfig::Options::UPO_RENAME_SAME_DIR : TransfConfig::Options::UnprocOrig(7);
+    CB_ASSERT (7 != opt.m_eUnprocOrigChange);
+    opt.m_bUnprocOrigUseLabel = m_pUOUseLabelRB->isChecked();
+    opt.m_bUnprocOrigAlwayUseCounter = m_pUOAlwaysUseCounterRB->isChecked();
+
+    opt.m_eProcessedCreate = m_pProcDontCreateRB->isChecked() ? TransfConfig::Options::PR_DONT_CREATE : m_pProcCreateAlwaysChangeRB->isChecked() ? TransfConfig::Options::PR_CREATE_ALWAYS_RENAME : m_pProcCreateChangeIfNeededRB->isChecked() ? TransfConfig::Options::PR_CREATE_RENAME_IF_USED : TransfConfig::Options::Processed(3);
+    CB_ASSERT (3 != opt.m_eProcessedCreate);
+    opt.m_bProcessedUseLabel = m_pProcUseLabelRB->isChecked();
+    opt.m_bProcessedAlwayUseCounter = m_pProcAlwaysUseCounterRB->isChecked();
+    opt.m_bProcessedUseSeparateDir = m_pProcUseSeparateDirRB->isChecked();
+
+    opt.m_bTempCreate = m_pTempCreateRB->isChecked();
+
+    opt.m_bCompCreate = m_pCompCreateRB->isChecked();
+
+    return opt;
+}
+
+
+TransfConfig::Options ConfigDlgImpl::getOpt() // has the correct m_bKeepOrigTime
+{
+    TransfConfig::Options opt (m_pSimpleViewB->isChecked() ? getSimpleViewOpt() : getFullViewOpt());
+    opt.m_bKeepOrigTime = m_pKeepOrigTimeCkB->isChecked();
+    return opt;
+}
+
+
+void ConfigDlgImpl::setSimpleViewOpt(const TransfConfig::Options& opt) // m_bKeepOrigTime shouldn't be set
+{
+    if (opt == opt.asNonBackup())
+    {
+        m_pDontCreateBackupRB->setChecked(true);
+    }
+    else if (opt == opt.asBackup())
+    {
+        m_pCreateBackupRB->setChecked(true);
+    }
+    else
+    {
+        m_pBackupCustomRB->setChecked(true);
+    }
+}
+
+
+void ConfigDlgImpl::setFullViewOpt(const TransfConfig::Options& opt) // m_bKeepOrigTime is ignored
+{
+    { // ProcOrig
+        switch (opt.m_eProcOrigChange)
+        {
+        case TransfConfig::Options::PO_DONT_CHG: m_pPODontChangeRB->setChecked(true); break;
+        case TransfConfig::Options::PO_ERASE: m_pPOEraseRB->setChecked(true); break;
+        case TransfConfig::Options::PO_MOVE_ALWAYS_RENAME: m_pPOMoveAlwaysChangeRB->setChecked(true); break;
+        case TransfConfig::Options::PO_MOVE_RENAME_IF_USED: m_pPOMoveChangeIfNeededRB->setChecked(true); break;
+        case TransfConfig::Options::PO_RENAME_SAME_DIR: m_pPOChangeNameRB->setChecked(true); break;
+        case TransfConfig::Options::PO_MOVE_OR_ERASE: m_pPOMoveOrEraseRB->setChecked(true); break;
+        default:
+            CB_ASSERT(false); // the constructor of TransfConfig should have detected it
+        }
+
+        if (opt.m_bProcOrigUseLabel) { m_pPOUseLabelRB->setChecked(true); } else { m_pPODontUseLabelRB->setChecked(true); }
+        if (opt.m_bProcOrigAlwayUseCounter) { m_pPOAlwaysUseCounterRB->setChecked(true); } else { m_pPOUseCounterIfNeededRB->setChecked(true); }
+    }
+
+    { // UnprocOrig
+        switch (opt.m_eUnprocOrigChange)
+        {
+        case TransfConfig::Options::UPO_DONT_CHG: m_pUODontChangeRB->setChecked(true); break;
+        case TransfConfig::Options::UPO_ERASE: m_pUOEraseRB->setChecked(true); break;
+        case TransfConfig::Options::UPO_MOVE_ALWAYS_RENAME: m_pUOMoveAlwaysChangeRB->setChecked(true); break;
+        case TransfConfig::Options::UPO_MOVE_RENAME_IF_USED: m_pUOMoveChangeIfNeededRB->setChecked(true); break;
+        case TransfConfig::Options::UPO_RENAME_SAME_DIR: m_pUOChangeNameRB->setChecked(true); break;
+        default:
+            CB_ASSERT(false); // the constructor of TransfConfig should have detected it
+        }
+
+        if (opt.m_bUnprocOrigUseLabel) { m_pUOUseLabelRB->setChecked(true); } else { m_pUODontUseLabelRB->setChecked(true); }
+        if (opt.m_bUnprocOrigAlwayUseCounter) { m_pUOAlwaysUseCounterRB->setChecked(true); } else { m_pUOUseCounterIfNeededRB->setChecked(true); }
+
+    }
+
+    { // Processed
+        switch (opt.m_eProcessedCreate)
+        {
+        case TransfConfig::Options::PR_DONT_CREATE: m_pProcDontCreateRB->setChecked(true); break;
+        case TransfConfig::Options::PR_CREATE_ALWAYS_RENAME: m_pProcCreateAlwaysChangeRB->setChecked(true); break;
+        case TransfConfig::Options::PR_CREATE_RENAME_IF_USED: m_pProcCreateChangeIfNeededRB->setChecked(true); break;
+        default:
+            CB_ASSERT(false); // the constructor of TransfConfig should have detected it
+        }
+
+        if (opt.m_bProcessedUseLabel) { m_pProcUseLabelRB->setChecked(true); } else { m_pProcDontUseLabelRB->setChecked(true); }
+        if (opt.m_bProcessedAlwayUseCounter) { m_pProcAlwaysUseCounterRB->setChecked(true); } else { m_pProcUseCounterIfNeededRB->setChecked(true); }
+        if (opt.m_bProcessedUseSeparateDir) { m_pProcUseSeparateDirRB->setChecked(true); } else { m_pProcUseSrcRB->setChecked(true); }
+    }
+
+    { // Temp
+        if (opt.m_bTempCreate) { m_pTempCreateRB->setChecked(true); } else { m_pTempDontCreateRB->setChecked(true); }
+    }
+
+    { // Comp
+        if (opt.m_bCompCreate) { m_pCompCreateRB->setChecked(true); } else { m_pCompDontCreateRB->setChecked(true); }
+    }
+}
+
+
+void ConfigDlgImpl::on_m_pSimpleViewB_clicked()
+{
+    m_pFileSettingsLayout->setCurrentWidget(m_pSimpleViewTab);
+    m_pFullViewB->setChecked(false);
+    m_pPODest2E->setText(m_pPODestE->text());
+    setSimpleViewOpt(getFullViewOpt());
+}
+
+void ConfigDlgImpl::on_m_pFullViewB_clicked()
+{
+    m_pFileSettingsLayout->setCurrentWidget(m_pFullViewTab);
+    m_pSimpleViewB->setChecked(false);
+    m_pPODestE->setText(m_pPODest2E->text());
+    setFullViewOpt(getSimpleViewOpt());
+}
+
+
 //=====================================================================================================================
 //=====================================================================================================================
 //=====================================================================================================================
 
 //ttt2 dir config: perhaps something simpler, with a "more options" button
 
-//ttt1 Font style is ignored (see DejaVu Sans / Light on machines with antialiased fonts)
+//ttt2 Font style is ignored (see DejaVu Sans / Light on machines with antialiased fonts)
+
+//ttt2 proxy: QNetworkProxyFactory::systemProxyForQuery; QNetworkProxy; http://www.dbits.be/index.php/pc-problems/65-vistaproxycfg  https://sourceforge.net/projects/mp3diags/forums/forum/947207/topic/3415940
+
+
