@@ -24,13 +24,11 @@
 #include  <QDesktopServices>
 
 #ifndef WIN32
+    #include  <sys/time.h>
 #else
     #include  <windows.h>
-    #include  <QDateTime>
 #endif
 
-#include  <sys/time.h>
-
 #include  <QDateTime>
 
 #include  "MusicBrainzDownloader.h"
@@ -123,6 +121,8 @@ struct AlbumXmlHandler : public SimpleSaxHandler<AlbumXmlHandler>
                             Node& trackArtistName (makeNode(trackArtist, "name")); trackArtistName.onChar = &AlbumXmlHandler::onTrackArtistName;
                 Node& relationList (makeNode(rel, "relation-list")); relationList.onStart = &AlbumXmlHandler::onRelationListStart;
                     Node& relation (makeNode(relationList, "relation")); relation.onStart = &AlbumXmlHandler::onRelationStart;
+
+        m_albumInfo.m_eVarArtists = AlbumInfo::VA_SINGLE;
     }
 
 private:
@@ -179,7 +179,7 @@ private:
                     m_albumInfo.m_vstrImageNames.push_back(strUrl);
                 }
                 else
-                { //ttt1 perhaps tell the user
+                { //ttt2 perhaps tell the user
                     qDebug("Unsupported image link");
                 }
             }
@@ -211,12 +211,16 @@ private:
     void onAsinChar(const string& s)
     {
         m_albumInfo.m_strAsin = s;
-        m_albumInfo.m_vstrImageNames.push_back("http://images.amazon.com/images/P/" + s + ".01.LZZZZZZZ.jpg"); // ttt1 "01" is country code for US, perhaps try others //ttt1 perhaps check for duplicates
+        m_albumInfo.m_vstrImageNames.push_back("http://images.amazon.com/images/P/" + s + ".01.LZZZZZZZ.jpg"); // ttt2 "01" is country code for US, perhaps try others //ttt2 perhaps check for duplicates
     }
 
     void onAlbArtistNameChar(const string& s)
     {
-        if (0 != convStr(s).compare("VaRiOuS Artists", Qt::CaseInsensitive))
+        if (0 == convStr(s).compare("VaRiOuS Artists", Qt::CaseInsensitive))
+        {
+            m_albumInfo.m_eVarArtists = AlbumInfo::VA_VARIOUS;
+        }
+        else
         {
             m_albumInfo.m_strArtist = s;
         }
@@ -234,8 +238,9 @@ private:
 };
 
 
-void MusicBrainzAlbumInfo::copyTo(AlbumInfo& dest)
+/*override*/ void MusicBrainzAlbumInfo::copyTo(AlbumInfo& dest)
 {
+
     dest.m_strTitle = m_strTitle;
     //dest.m_strArtist = m_strArtist;
     //dest.m_strComposer; // !!! missing
@@ -244,6 +249,7 @@ void MusicBrainzAlbumInfo::copyTo(AlbumInfo& dest)
     dest.m_strReleased = m_strReleased;
     //dest.m_strNotes; // !!! missing
     dest.m_vTracks = m_vTracks;
+    dest.m_eVarArtists = m_eVarArtists;
 
     dest.m_strSourceName = MusicBrainzDownloader::SOURCE_NAME; // Discogs, MusicBrainz, ... ; needed by MainFormDlgImpl;
     //dest.m_imageInfo; // !!! not set
@@ -284,6 +290,8 @@ MusicBrainzDownloader::MusicBrainzDownloader(QWidget* pParent, SessionSettings&
 
     m_pVolumeL->hide(); m_pVolumeCbB->hide();
 
+    m_pStyleL->hide(); m_pStyleCbB->hide();
+
     m_pImgSizeL->setMinimumHeight(m_pImgSizeL->height()*2);
 
     m_pQHttp->setHost("musicbrainz.org");
@@ -308,6 +316,7 @@ MusicBrainzDownloader::~MusicBrainzDownloader()
 
 void MusicBrainzDownloader::clear()
 {
+LAST_STEP("MusicBrainzDownloader::clear");
     clearPtrContainer(m_vpImages);
     m_vAlbums.clear();
 }
@@ -317,6 +326,7 @@ void MusicBrainzDownloader::clear()
 
 /*override*/ bool MusicBrainzDownloader::initSearch(const std::string& strArtist, const std::string& strAlbum)
 {
+LAST_STEP("MusicBrainzDownloader::initSearch");
     m_pSrchArtistE->setText(convStr((removeParentheses(strArtist))));
     m_pSrchAlbumE->setText(convStr((removeParentheses(strAlbum))));
     return !strArtist.empty() || !strAlbum.empty();
@@ -327,7 +337,8 @@ void MusicBrainzDownloader::clear()
 
 /*override*/ std::string MusicBrainzDownloader::createQuery()
 {
-    string s ("/ws/1/release/?type=xml&artist=" + convStr(m_pSrchArtistE->text()) + "&title=" + convStr(m_pSrchAlbumE->text()));
+LAST_STEP("MusicBrainzDownloader::createQuery");
+    string s ("/ws/1/release/?type=xml&artist=" + replaceSymbols(convStr(m_pSrchArtistE->text())) + "&title=" + replaceSymbols(convStr(m_pSrchAlbumE->text())));
     //qDebug("qry: %s", s.c_str());
     if (m_pMatchCountCkB->isChecked())
     {
@@ -403,6 +414,7 @@ qDebug("t2 %lld", tv.tv_sec*1000LL + tv.tv_usec/1000);
 
 void MusicBrainzDownloader::on_m_pSearchB_clicked()
 {
+LAST_STEP("MusicBrainzDownloader::on_m_pSearchB_clicked");
     clear();
     search();
 }
@@ -418,7 +430,10 @@ void MusicBrainzDownloader::on_m_pSearchB_clicked()
 
 void MusicBrainzDownloader::loadNextPage()
 {
-    CB_ASSERT (!m_pQHttp->hasPendingRequests() && !m_pImageQHttp->hasPendingRequests());
+LAST_STEP("MusicBrainzDownloader::loadNextPage");
+    CB_ASSERT (!m_pQHttp->hasPendingRequests());
+    CB_ASSERT (!m_pImageQHttp->hasPendingRequests());
+
     ++m_nLastLoadedPage;
     CB_ASSERT (m_nLastLoadedPage <= m_nTotalPages - 1);
 
@@ -433,17 +448,18 @@ void MusicBrainzDownloader::loadNextPage()
     header.setValue("Host", "musicbrainz.org");
     //header.setValue("Accept-Encoding", "gzip");
     delay();
-    //qDebug("--------------\npath %s", header.path().toUtf8().data());
+    //qDebug("--------------\npath %s", header.path().toUtf8().constData());
     //qDebug("qry %s", m_strQuery.c_str());
     m_pQHttp->request(header);
     //cout << "sent search " << m_pQHttp->request(header) << " for page " << (m_nLastLoadedPage + 1) << endl;
 }
 
 
-//ttt1 see if it is possible for a track to have its own genre
+//ttt2 see if it is possible for a track to have its own genre
 
 QString MusicBrainzDownloader::getAmazonText() const
 {
+LAST_STEP("MusicBrainzDownloader::getAmazonText");
     if (m_nCrtAlbum < 0 || m_nCrtAlbum >= cSize(m_vAlbums))
     {
         return NOT_FOUND_AT_AMAZON;
@@ -462,6 +478,7 @@ QString MusicBrainzDownloader::getAmazonText() const
 
 void MusicBrainzDownloader::onAmazonLinkActivated(const QString& qstrLink) // !!! it's possible to set openExternalLinks on a QLabel to open links automatically, but this leaves an ugly frame around the text, with it right side missing; also, manual handling is needed to open a built-in browser;
 {
+LAST_STEP("MusicBrainzDownloader::onAmazonLinkActivated");
     m_pViewAtAmazonL->setText("qq"); // !!! the text needs to CHANGE to make the frame disappear
     m_pViewAtAmazonL->setText(getAmazonText());
 
@@ -472,6 +489,7 @@ void MusicBrainzDownloader::onAmazonLinkActivated(const QString& qstrLink) // !!
 
 void MusicBrainzDownloader::reloadGui()
 {
+LAST_STEP("MusicBrainzDownloader::reloadGui");
     AlbumInfoDownloaderDlgImpl::reloadGui();
     m_pViewAtAmazonL->setText(getAmazonText());
 }
@@ -479,7 +497,11 @@ void MusicBrainzDownloader::reloadGui()
 
 void MusicBrainzDownloader::requestAlbum(int nAlbum)
 {
-    CB_ASSERT (!m_pQHttp->hasPendingRequests() && !m_pImageQHttp->hasPendingRequests());
+LAST_STEP("MusicBrainzDownloader::requestAlbum");
+    //CB_ASSERT (!m_pQHttp->hasPendingRequests() && !m_pImageQHttp->hasPendingRequests());  // ttt1 triggered: https://sourceforge.net/apps/mantisbt/mp3diags/view.php?id=36 ?? perhaps might happen when MB returns errors ; see also DiscogsDownloader::requestAlbum
+    CB_ASSERT (!m_pQHttp->hasPendingRequests());
+    CB_ASSERT (!m_pImageQHttp->hasPendingRequests());
+
     m_nLoadingAlbum = nAlbum;
     setWaiting(ALBUM);
     //string s ("/release/" + m_vAlbums[nAlbum].m_strId + "?f=xml&api_key=f51e9c8f6c");
@@ -498,7 +520,9 @@ void MusicBrainzDownloader::requestAlbum(int nAlbum)
 
 void MusicBrainzDownloader::requestImage(int nAlbum, int nImage)
 {
-    CB_ASSERT (!m_pQHttp->hasPendingRequests() && !m_pImageQHttp->hasPendingRequests());
+LAST_STEP("MusicBrainzDownloader::requestImage");
+    CB_ASSERT (!m_pQHttp->hasPendingRequests());
+    CB_ASSERT (!m_pImageQHttp->hasPendingRequests());
 
     m_nLoadingAlbum = nAlbum;
     m_nLoadingImage = nImage;
@@ -511,7 +535,7 @@ void MusicBrainzDownloader::requestImage(int nAlbum, int nImage)
 
     delay(); // probably not needed, because doesn't seem that MusicBrainz would want to store images
     //connect(m_pImageQHttp, SIGNAL(requestFinished(int, bool)), this, SLOT(onRequestFinished(int, bool)));
-    //qDebug("host: %s, path: %s", url.host().toLatin1().data(), url.path().toLatin1().data());
+    //qDebug("host: %s, path: %s", url.host().toLatin1().constData(), url.path().toLatin1().constData());
     //qDebug("%s", strUrl.c_str());
     m_pImageQHttp->get(url.path());
 
@@ -526,11 +550,13 @@ void MusicBrainzDownloader::requestImage(int nAlbum, int nImage)
 
 /*override*/ QHttp* MusicBrainzDownloader::getWaitingHttp()
 {
+LAST_STEP("MusicBrainzDownloader::getWaitingHttp");
     return IMAGE == m_eWaiting ? m_pImageQHttp : m_pQHttp;
 }
 
 /*override*/ void MusicBrainzDownloader::resetNavigation()
 {
+LAST_STEP("MusicBrainzDownloader::resetNavigation");
     m_pImageQHttp->clearPendingRequests();
     AlbumInfoDownloaderDlgImpl::resetNavigation();
 }
@@ -575,10 +601,10 @@ void MusicBrainzDownloader::requestImage(int nAlbum, int nImage)
 */
 
 
-//ttt1 perhaps look at Last.fm for more pictures (see Cover Fetcher for AmaroK 1.4; a brief look at the API seems to indicate that a generic "search" is not possible)
+//ttt2 perhaps look at Last.fm for more pictures (see Cover Fetcher for AmaroK 1.4; a brief look at the API seems to indicate that a generic "search" is not possible)
 
 
-//ttt1 detect Qt 4.4 and use QWebView
+//ttt2 detect Qt 4.4 and use QWebView
 #endif
 
 
